==> npr-3.7.3-en-download.zip: npr-3.7.3-en/webhelp/npr-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entiresystemserver
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entiresystemserver = {
    baseurls: ["../"],
    varname: "entiresystemserver",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf-over.htm", title: "Concepts and Facilities" },
            { url: "cnf/cnf_what.htm", title: "What is Entire System Server?" },
            { url: "cnf/cnf_ben.htm", title: "Benefits of Using the Entire System Server" },
            { url: "cnf/cnf_ex.htm", title: "Entire System Server at Work - Examples" },
            { url: "rnotes/rnotes-over.htm", title: "Release Notes - Overview" },
            { url: "rnotes/rnotes_v373.htm", title: "Entire System Server 3.7.3 Release Notes" },
            { url: "rnotes/rnotes_v372.htm", title: "Entire System Server 3.7.2 Release Notes" },
            { url: "rnotes/rnotes_v371.htm", title: "Entire System Server 3.7.1 Release Notes" },
            { url: "rnotes/rnotes_v363.htm", title: "Entire System Server 3.6.3 Release Notes" },
            { url: "rnotes/rnotes_v362.htm", title: "Entire System Server 3.6.2 Release Notes" },
            { url: "rnotes/rnotes_v361.htm", title: "Entire System Server 3.6.1 Release Notes" },
            { url: "rnotes/rnotes_v354.htm", title: "Entire System Server 3.5.4 Release Notes" },
            { url: "rnotes/rnotes_v353.htm", title: "Entire System Server 3.5.3 Release Notes" },
            { url: "rnotes/rnotes_v352.htm", title: "Entire System Server 3.5.2 Release Notes" },
            { url: "rnotes/rnotes_v351.htm", title: "Entire System Server 3.5.1 Release Notes" },
            { url: "rnotes/rnotes_v342.htm", title: "Entire System Server 3.4.2 Release Notes" },
            { url: "rnotes/rnotes_v341.htm", title: "Entire System Server 3.4.1 Release Notes" },
            { url: "rnotes/rnotes_v332.htm", title: "Entire System Server 3.3.2 Release Notes" },
            { url: "rnotes/rnotes_v331.htm", title: "Entire System Server 3.3.1 Release Notes" },
            { url: "license/license.htm", title: "Software AG Mainframe Product Licensing" },
            { url: "inst/inst-over.htm", title: "Installation and Customization" },
            { url: "inst/inst_intro.htm", title: "Introduction" },
            { url: "inst/inst_zos.htm", title: "Installation for z/OS" },
            { url: "ug/ug-over.htm", title: "User's Guide" },
            { url: "ug/ug_intro.htm", title: "Introduction" },
            { url: "ug/ug_start.htm", title: "Getting Started" },
            { url: "ug/ug_tut.htm", title: "Online Tutorial" },
            { url: "ug/ug_vd-over.htm", title: "View Descriptions" },
            { url: "ug/ug_vd_account.htm", title: "ACCOUNTING" },
            { url: "ug/ug_vd_active.htm", title: "ACTIVE-JOBS" },
            { url: "ug/ug_vd_address.htm", title: "ADDRESS-SPACE" },
            { url: "ug/ug_vd_alloca.htm", title: "ALLOCATIONS" },
            { url: "ug/ug_vd_archive.htm", title: "ARCHIVE" },
            { url: "ug/ug_vd_authorized_libs.htm", title: "AUTHORIZED-LIBRARIES" },
            { url: "ug/ug_vd_catalog.htm", title: "CATALOG" },
            { url: "ug/ug_vd_catalogu.htm", title: "CATALOG-UPDATE" },
            { url: "ug/ug_vd_check.htm", title: "CHECK-SECURITY" },
            { url: "ug/ug_vd_common.htm", title: "COMMON-DATA" },
            { url: "ug/ug_vd_console.htm", title: "CONSOLE" },
            { url: "ug/ug_vd_consolel.htm", title: "CONSOLE-LOG" },
            { url: "ug/ug_vd_copyfile.htm", title: "COPY-FILE" },
            { url: "ug/ug_vd_device.htm", title: "DEVICE-NAMES" },
            { url: "ug/ug_vd_enter-procedure.htm", title: "ENTER-PROCEDURE" },
            { url: "ug/ug_vd_event.htm", title: "EVENTING" },
            { url: "ug/ug_vd_fileallo.htm", title: "FILE-ALLOCATE" },
            { url: "ug/ug_vd_fileattr.htm", title: "FILE-ATTRIBUTES" },
            { url: "ug/ug_vd_filemain.htm", title: "FILE-MAINTENANCE" },
            { url: "ug/ug_vd_helpinfo.htm", title: "HELP-INFO" },
            { url: "ug/ug_vd_idcams.htm", title: "IDCAMS" },
            { url: "ug/ug_vd_iebcopy.htm", title: "IEBCOPY" },
            { url: "ug/ug_vd_itc.htm", title: "ITC" },
            { url: "ug/ug_vd_jobswit.htm", title: "JOB-SWITCHES" },
            { url: "ug/ug_vd_jobvari.htm", title: "JOB-VARIABLES" },
            { url: "ug/ug_vd_libdir.htm", title: "LIB-DIRECTORY" },
            { url: "ug/ug_vd_libupda.htm", title: "LIB-UPDATE" },
            { url: "ug/ug_vd_libzap.htm", title: "LIB-ZAP" },
            { url: "ug/ug_vd_loaded.htm", title: "LOADED-MODULES" },
            { url: "ug/ug_vd_loadmodu.htm", title: "LOAD-MODULE" },
            { url: "ug/ug_vd_mainstor.htm", title: "MAIN-STORAGE" },
            { url: "ug/ug_vd_natprocl.htm", title: "NATPROC-LOGON" },
            { url: "ug/ug_vd_natprocu.htm", title: "NATPROC-USERS" },
            { url: "ug/ug_vd_netoper.htm", title: "NET-OPER" },
            { url: "ug/ug_vd_print-document.htm", title: "PRINT-DOCUMENT" },
            { url: "ug/ug_vd_readfile.htm", title: "READ-FILE" },
            { url: "ug/ug_vd_readspoo.htm", title: "READ-SPOOL" },
            { url: "ug/ug_vd_readuf.htm", title: "READ-UNIX-FILE" },
            { url: "ug/ug_vd_reveive-email.htm", title: "RECEIVE-EMAIL" },
            { url: "ug/ug_vd_resource.htm", title: "RESOURCE-CONTROL" },
            { url: "ug/ug_vd_sendeml.htm", title: "SEND-EMAIL" },
            { url: "ug/ug_vd_send.htm", title: "SEND-MESSAGE" },
            { url: "ug/ug_vd_spoolf.htm", title: "SPOOL-FILES" },
            { url: "ug/ug_vd_spoolq.htm", title: "SPOOL-QUEUE" },
            { url: "ug/ug_vd_spoolu.htm", title: "SPOOL-UPDATE" },
            { url: "ug/ug_vd_submit.htm", title: "SUBMIT" },
            { url: "ug/ug_vd_systemc.htm", title: "SYSTEM-COMMAND" },
            { url: "ug/ug_vd_systemi.htm", title: "SYSTEM-INFO" },
            { url: "ug/ug_vd_task.htm", title: "TASK-INFO" },
            { url: "ug/ug_vd_tcb.htm", title: "TCB" },
            { url: "ug/ug_vd_unitattr.htm", title: "UNIT-ATTRIBUTES" },
            { url: "ug/ug_vd_unixdir.htm", title: "UNIX-DIRECTORY" },
            { url: "ug/ug_vd_userattr.htm", title: "USER-ATTRIBUTES" },
            { url: "ug/ug_vd_vtoc.htm", title: "VTOC" },
            { url: "ug/ug_vd_vtocupda.htm", title: "VTOC-UPDATE" },
            { url: "ug/ug_vd_writef.htm", title: "WRITE-FILE" },
            { url: "ug/ug_vd_writes.htm", title: "WRITE-SPOOL" },
            { url: "ug/ug_vd_writeuf.htm", title: "WRITE-UNIX-FILE" },
            { url: "ug/ug_rel_literature.htm", title: "Related Literature" },
            { url: "mc/mc-over.htm", title: "Messages and Codes" },
            { url: "mc/mc_sysm.htm", title: "System Messages" },
            { url: "mc/mc_conmx.htm", title: "XCO Console Messages" },
            { url: "mc/mc_conme.htm", title: "ESY Console Messages" },
            { url: "mc/nucresp.htm", title: "Adabas Response Codes" },
            { url: "admin/admin-over.htm", title: "Administration" },
            { url: "admin/admin_use.htm", title: "Using the Entire System Server" },
            { url: "admin/admin_start-over.htm", title: "Startup Parameters" },
            { url: "admin/admin_startintro.htm", title: "Introduction to Startup Parameters" },
            { url: "admin/admin_startlst.htm", title: "Startup Parameters in Alphabetical Order" },
            { url: "admin/admin_opcm.htm", title: "Operator Commands" },
            { url: "admin/admin_comfeat.htm", title: "Common Entire System Server Features" },
            { url: "admin/admin_zoscon.htm", title: "z/OS Considerations" },
            { url: "admin/admin_vsecon.htm", title: "z/VSE Considerations" },
            { url: "admin/admin_bs2con.htm", title: "BS2000 Considerations" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entiresystemserver });

==> npr-3.8.1-en-download.zip: npr-3.8.1-en/webhelp/npr-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entiresystemserver
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entiresystemserver = {
    baseurls: ["../"],
    varname: "entiresystemserver",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "cnf/cnf-over.htm", title: "Concepts and Facilities" },
            { url: "cnf/cnf_what.htm", title: "What is Entire System Server?" },
            { url: "cnf/cnf_ben.htm", title: "Benefits of Using the Entire System Server" },
            { url: "cnf/cnf_ex.htm", title: "Entire System Server at Work - Examples" },
            { url: "rnotes/rnotes-over.htm", title: "Release Notes - Overview" },
            { url: "rnotes/rnotes_v381.htm", title: "Entire System Server 3.8.1 Release Notes" },
            { url: "rnotes/rnotes_v373.htm", title: "Entire System Server 3.7.3 Release Notes" },
            { url: "rnotes/rnotes_v372.htm", title: "Entire System Server 3.7.2 Release Notes" },
            { url: "rnotes/rnotes_v371.htm", title: "Entire System Server 3.7.1 Release Notes" },
            { url: "rnotes/rnotes_v363.htm", title: "Entire System Server 3.6.3 Release Notes" },
            { url: "rnotes/rnotes_v362.htm", title: "Entire System Server 3.6.2 Release Notes" },
            { url: "rnotes/rnotes_v361.htm", title: "Entire System Server 3.6.1 Release Notes" },
            { url: "rnotes/rnotes_v354.htm", title: "Entire System Server 3.5.4 Release Notes" },
            { url: "rnotes/rnotes_v353.htm", title: "Entire System Server 3.5.3 Release Notes" },
            { url: "rnotes/rnotes_v352.htm", title: "Entire System Server 3.5.2 Release Notes" },
            { url: "rnotes/rnotes_v351.htm", title: "Entire System Server 3.5.1 Release Notes" },
            { url: "rnotes/rnotes_v342.htm", title: "Entire System Server 3.4.2 Release Notes" },
            { url: "rnotes/rnotes_v341.htm", title: "Entire System Server 3.4.1 Release Notes" },
            { url: "rnotes/rnotes_v332.htm", title: "Entire System Server 3.3.2 Release Notes" },
            { url: "rnotes/rnotes_v331.htm", title: "Entire System Server 3.3.1 Release Notes" },
            { url: "license/license.htm", title: "Mainframe Product Licensing" },
            { url: "inst/inst-over.htm", title: "Installation and Customization" },
            { url: "inst/inst_intro.htm", title: "Introduction" },
            { url: "inst/inst_zos.htm", title: "Installation for z/OS" },
            { url: "ug/ug-over.htm", title: "User's Guide" },
            { url: "ug/ug_intro.htm", title: "Introduction" },
            { url: "ug/ug_start.htm", title: "Getting Started" },
            { url: "ug/ug_tut.htm", title: "Online Tutorial" },
            { url: "ug/ug_vd-over.htm", title: "View Descriptions" },
            { url: "ug/ug_vd_account.htm", title: "ACCOUNTING" },
            { url: "ug/ug_vd_active.htm", title: "ACTIVE-JOBS" },
            { url: "ug/ug_vd_address.htm", title: "ADDRESS-SPACE" },
            { url: "ug/ug_vd_alloca.htm", title: "ALLOCATIONS" },
            { url: "ug/ug_vd_authorized_libs.htm", title: "AUTHORIZED-LIBRARIES" },
            { url: "ug/ug_vd_catalog.htm", title: "CATALOG" },
            { url: "ug/ug_vd_catalogu.htm", title: "CATALOG-UPDATE" },
            { url: "ug/ug_vd_check.htm", title: "CHECK-SECURITY" },
            { url: "ug/ug_vd_common.htm", title: "COMMON-DATA" },
            { url: "ug/ug_vd_console.htm", title: "CONSOLE" },
            { url: "ug/ug_vd_consolel.htm", title: "CONSOLE-LOG" },
            { url: "ug/ug_vd_copyfile.htm", title: "COPY-FILE" },
            { url: "ug/ug_vd_device.htm", title: "DEVICE-NAMES" },
            { url: "ug/ug_vd_event.htm", title: "EVENTING" },
            { url: "ug/ug_vd_fileallo.htm", title: "FILE-ALLOCATE" },
            { url: "ug/ug_vd_fileattr.htm", title: "FILE-ATTRIBUTES" },
            { url: "ug/ug_vd_filemain.htm", title: "FILE-MAINTENANCE" },
            { url: "ug/ug_vd_idcams.htm", title: "IDCAMS" },
            { url: "ug/ug_vd_iebcopy.htm", title: "IEBCOPY" },
            { url: "ug/ug_vd_libdir.htm", title: "LIB-DIRECTORY" },
            { url: "ug/ug_vd_libupda.htm", title: "LIB-UPDATE" },
            { url: "ug/ug_vd_libzap.htm", title: "LIB-ZAP" },
            { url: "ug/ug_vd_loaded.htm", title: "LOADED-MODULES" },
            { url: "ug/ug_vd_loadmodu.htm", title: "LOAD-MODULE" },
            { url: "ug/ug_vd_mainstor.htm", title: "MAIN-STORAGE" },
            { url: "ug/ug_vd_natprocl.htm", title: "NATPROC-LOGON" },
            { url: "ug/ug_vd_natprocu.htm", title: "NATPROC-USERS" },
            { url: "ug/ug_vd_netoper.htm", title: "NET-OPER" },
            { url: "ug/ug_vd_readfile.htm", title: "READ-FILE" },
            { url: "ug/ug_vd_readspoo.htm", title: "READ-SPOOL" },
            { url: "ug/ug_vd_readuf.htm", title: "READ-UNIX-FILE" },
            { url: "ug/ug_vd_reveive-email.htm", title: "RECEIVE-EMAIL" },
            { url: "ug/ug_vd_resource.htm", title: "RESOURCE-CONTROL" },
            { url: "ug/ug_vd_sendeml.htm", title: "SEND-EMAIL" },
            { url: "ug/ug_vd_send.htm", title: "SEND-MESSAGE" },
            { url: "ug/ug_vd_spoolf.htm", title: "SPOOL-FILES" },
            { url: "ug/ug_vd_spoolq.htm", title: "SPOOL-QUEUE" },
            { url: "ug/ug_vd_spoolu.htm", title: "SPOOL-UPDATE" },
            { url: "ug/ug_vd_submit.htm", title: "SUBMIT" },
            { url: "ug/ug_vd_systemc.htm", title: "SYSTEM-COMMAND" },
            { url: "ug/ug_vd_systemi.htm", title: "SYSTEM-INFO" },
            { url: "ug/ug_vd_tcb.htm", title: "TCB" },
            { url: "ug/ug_vd_unitattr.htm", title: "UNIT-ATTRIBUTES" },
            { url: "ug/ug_vd_unixdir.htm", title: "UNIX-DIRECTORY" },
            { url: "ug/ug_vd_vtoc.htm", title: "VTOC" },
            { url: "ug/ug_vd_vtocupda.htm", title: "VTOC-UPDATE" },
            { url: "ug/ug_vd_writef.htm", title: "WRITE-FILE" },
            { url: "ug/ug_vd_writes.htm", title: "WRITE-SPOOL" },
            { url: "ug/ug_vd_writeuf.htm", title: "WRITE-UNIX-FILE" },
            { url: "ug/ug_rel_literature.htm", title: "Related Literature" },
            { url: "mc/mc-over.htm", title: "Messages and Codes" },
            { url: "mc/mc_sysm.htm", title: "System Messages" },
            { url: "mc/mc_conmx.htm", title: "XCO Console Messages" },
            { url: "mc/mc_conme.htm", title: "ESY Console Messages" },
            { url: "mc/nucresp.htm", title: "Adabas Response Codes" },
            { url: "admin/admin-over.htm", title: "Administration" },
            { url: "admin/admin_use.htm", title: "Using the Entire System Server" },
            { url: "admin/admin_start-over.htm", title: "Startup Parameters" },
            { url: "admin/admin_startintro.htm", title: "Introduction to Startup Parameters" },
            { url: "admin/admin_startlst.htm", title: "Startup Parameters in Alphabetical Order" },
            { url: "admin/admin_opcm.htm", title: "Operator Commands" },
            { url: "admin/admin_comfeat.htm", title: "Common Entire System Server Features" },
            { url: "admin/admin_zoscon.htm", title: "Considerations" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entiresystemserver });
